translate.storage.statsdb.FileTotals

Package translate :: Package storage :: Module statsdb :: Class FileTotals |
[hide private]
[frames] | no frames]

# Class FileTotals

source code

Instance Methods | [hide private]
db_keys(self) | source code
__init__(self, cur) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__getitem__(self, fileid) | source code
__setitem__(self, fileid, record) | source code
__delitem__(self, fileid) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods | [hide private]
new_record(cls, state_for_db=None, sourcewords=None, targetwords=None) | source code
_compute_derived_values(cls, record) | source code

Class Variables | [hide private]
| keys = ``[``'``translatedsourcewords``'``,` `'``fuzzysourcewords``'``,` `'``untransl``...``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, cur) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### keys Value:
      ['translatedsourcewords',
       'fuzzysourcewords',
       'untranslatedsourcewords',
       'translated',
       'fuzzy',
       'untranslated',
       'translatedtargetwords']